Documentation
¶
Index ¶
- Constants
- func NewDispatcher(uploaders []Uploader) *dispatcher
- func NewUploader(kustoCli *kusto.Client, opts UploaderOpts) *uploader
- type DropUnusedTablesTask
- type IngestionMapping
- type SampleType
- type StatementExecutor
- type SyncFunctionsTask
- type Syncer
- func (s *Syncer) Close() error
- func (s *Syncer) EnsureDefaultMapping(table string) (string, error)
- func (s *Syncer) EnsureDefaultTable(table string) error
- func (s *Syncer) EnsureMapping(table string, mapping schema.SchemaMapping) (string, error)
- func (s *Syncer) EnsureTable(table string, mapping schema.SchemaMapping) error
- func (s *Syncer) Open(ctx context.Context) error
- type Table
- type TableDetail
- type Uploader
- type UploaderOpts
Constants ¶
const ConcurrentUploads = 50
Variables ¶
This section is empty.
Functions ¶
func NewDispatcher ¶
func NewDispatcher(uploaders []Uploader) *dispatcher
func NewUploader ¶
func NewUploader(kustoCli *kusto.Client, opts UploaderOpts) *uploader
Types ¶
type DropUnusedTablesTask ¶
type DropUnusedTablesTask struct {
// contains filtered or unexported fields
}
func NewDropUnusedTablesTask ¶
func NewDropUnusedTablesTask(kustoCli StatementExecutor) *DropUnusedTablesTask
type IngestionMapping ¶
type StatementExecutor ¶
type StatementExecutor interface {
Database() string
Mgmt(ctx context.Context, query kusto.Statement, options ...kusto.MgmtOption) (*kusto.RowIterator, error)
}
type SyncFunctionsTask ¶
type SyncFunctionsTask struct {
// contains filtered or unexported fields
}
func NewSyncFunctionsTask ¶
func NewSyncFunctionsTask(store storage.Functions, kustoCli StatementExecutor) *SyncFunctionsTask
type Syncer ¶
type Syncer struct {
KustoCli mgmt
// contains filtered or unexported fields
}
func NewSyncer ¶
func NewSyncer(kustoCli mgmt, database string, defaultMapping schema.SchemaMapping, st SampleType) *Syncer
func (*Syncer) EnsureDefaultMapping ¶
EnsureMapping creates a schema mapping for the specified table if it does not exist. It returns the name of the mapping.
func (*Syncer) EnsureDefaultTable ¶
EnsureDefaultTable creates a table with the default schema mapping if it does not exist.
func (*Syncer) EnsureMapping ¶
EnsureMapping creates a schema mapping for the specified table if it does not exist. It returns the name of the mapping.
func (*Syncer) EnsureTable ¶
func (s *Syncer) EnsureTable(table string, mapping schema.SchemaMapping) error
EnsureTable creates a table with the specified schema mapping if it does not exist.
type TableDetail ¶
type Uploader ¶
type Uploader interface {
service.Component
Database() string
// UploadQueue returns a channel that can be used to upload files to kusto.
UploadQueue() chan *cluster.Batch
// Mgmt executes a management query against the database.
Mgmt(ctx context.Context, query kusto.Statement, options ...kusto.MgmtOption) (*kusto.RowIterator, error)
}
func NewFakeUploader ¶
type UploaderOpts ¶
type UploaderOpts struct {
StorageDir string
Database string
ConcurrentUploads int
Dimensions []string
DefaultMapping adxschema.SchemaMapping
SampleType SampleType
}
Click to show internal directories.
Click to hide internal directories.