ingestor

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 22, 2025 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

const (
	DefaultImage = "ingestor"
	DefaultTag   = "latest"
)

Variables

This section is empty.

Functions

func WithCluster

func WithCluster(ctx context.Context, k *k3s.K3sContainer) testcontainers.CustomizeRequestOption

func WithStarted

func WithStarted() testcontainers.CustomizeRequestOption

WithStarted will start the container when it is created. You don't want to do this if you want to load the container into a k8s cluster.

Types

type IngestorContainer

type IngestorContainer struct {
	testcontainers.Container
}

func Run

func Run(ctx context.Context, opts ...testcontainers.ContainerCustomizer) (*IngestorContainer, error)

type KustoTableSchema

type KustoTableSchema struct{}

func (*KustoTableSchema) CslColumns

func (k *KustoTableSchema) CslColumns() []string

func (*KustoTableSchema) TableName

func (k *KustoTableSchema) TableName() string

Jump to